@@ -1140,12 +1140,12 @@ class cloud:
         Tinit = np.array([self.Tg, self.Td])
 
         # Get luminosity scaling
-        rates = cloud.dEdt(c1Grav=c1Grav, thin=thin, LTE=LTE, \
+        rates = self.dEdt(c1Grav=c1Grav, thin=thin, LTE=LTE, \
                                escapeProbGeom=escapeProbGeom, \
                                sumOnly=True, PsiUser=PsiUser, \
                                noClump=noClump, \
                                verbose=verbose)
-        lumScale = zeros(2)
+        lumScale = np.zeros(2)
         lumScale[0] = rates['maxAbsdEdtGas']
         lumScale[1] = rates['maxAbsdEdtDust']
 
@@ -1516,167 +1516,6 @@ class cloud:
         return outDict
 
 
-########################################################################
-# Method to compute the line profile for a specified transition,
-# assuming that the gas is in LTE
-########################################################################
-    def lineProfLTE(self, emitName, u, l, offset=0.0, vOut=None, \
-                        vLim=None, \
-                        nOut=100, dv=None, denProf=None, \
-                        TProf=None, vProf=None, sigmaProf=None):
-        """
-        Return the brightness temperature versus velocity for a
-        specified line, assuming the level populations are in LTE.
-
-        Parameters
-        ----------
-        emitName : string
-            emitter for which the computation is to be made
-        u : int
-            upper state of line to be computed
-        l : int
-            lower state of line to be computed
-        offset : float
-                 fractional distance from cloud center at which
-                 measurement is made; 0 = at cloud center, 1 = at
-                 cloud edge; valid values are 0 - 1
-        vOut : array
-            array of velocities (relative to line center at 0) at
-            which the output is to be returned
-        vLim : array (2)
-            maximum and minimum velocities relative to line center at
-            which to compute TB
-        nOut : int
-            number of velocities at which to output
-        dv : float
-            velocity spacing at which to produce output
-        denProf : function denProf(r), r = float, returns float
-            function that returns density of the emitting species (in
-            H cm^-3) as a function of radius r within the cloud, where
-            r is normalized so that the cloud center is 0, and the
-            cloud edge is 1. If not set, the cloud density is assumed
-            to be uniform with value nH * abundance of emitter.
-        TProf : function Tprof(r), r = float, returns float
-            same as denProf, but returning temperature (in K)
-            vs. radius; if not set, temperature is taken to be Tg at
-            all points
-        vProf : function vProf(r), r = float, returns float
-            same as denProf, but returning radial velocity (in cm
-            s^-1) vs. r; the convention is that outward velocities are
-            positive; if not set, velocity is v + r dv/dr
-        sigmaProf : function sigmaProf(r), r = float, returns float
-            same as denProf, but returning the non-thermal velocity
-            dispersion (in cm s^-1) vs. r; if not set, this value is
-            taken to be sigmaNT at all points
-
-        Returns
-        -------
-        TB : array
-             brightness temperature as a function of velocity (in K)
-        vOut : array
-               velocities at which TB is computed (in cm s^-1)
-        """
-
-        # Step 1: safety check
-        if not emitName in self.emitters:
-            raise despoticError, 'unknown emitter '+emitName
-        if self.emitters[emitName].EinsteinA[u,l] == 0.0:
-            raise depoticError, 'no radiative transition from state ' \
-                +str(u)+' to state '+str(l)+' found for species ' \
-                +emitName
-        if offset < 0.0 or offset > 1.0:
-            raise despoticError, 'offset must be in the range 0 - 1'
-
-        # Step 2: construct list of velocities at which to output
-        if vOut == None:
-            if dv == None:
-                if vLim == None:
-                    # No input given, so take velocity limits to be
-                    # offset from line center by max of 3*sigma + v
-                    if sigmaProf == None:
-                        sigmaMax = self.sigmaNT
-                    else:
-                        sigmaMax = max(sigmaProf(0), sigmaProf(1))
-                    if vProf == None:
-                        vMax = abs(self.dVdr * self.colDen/self.nH)
-                    else:
-                        vMax = max(vProf(0), vProf(1))
-                    vLim = [-3*sigmaMax-vMax, 3*sigmaMax+vMax]
-                # Compute vOut from vLim and nOut
-                vOut = np.arange(vLim[0], vLim[1]*(1.0+1e-6), \
-                                  (vLim[1]-vLim[0])/nOut)
-            else:
-                # dv is non-zero, so set velocities from dv and nOut
-                vOut = np.arange(-dv*(nOut/2.0), \
-                                   dv*(nOut/2.0+1.0e-6), dv)
-
-        # Step 3: compute normalization constants
-        if TProf==None:
-            T0 = self.Tg
-        else:
-            T0 = TProf(1)
-        if sigmaProf==None:
-            sigma0 = self.sigmaNT
-        else:
-            sigma0 = sigmaProf(1)
-        if vProf==None:
-            v0 = self.dVdr * (self.colDen/self.nH)
-        else:
-            v0 = vProf(1)
-        if denProf==None:
-            d0 = self.nH * self.emitters[emitName].abundance
-        else:
-            d0 = denProf(1)
-
-        # Step 4: compute dimensionless ratios and scalings
-        cs0 = np.sqrt(kB*T0/(mH*self.emitters[emitName].molWgt))
-        beta = v0/c
-        betas0 = cs0/c
-        betas = sigma0 / cs0
-        wavelength = c / self.emitters[emitName].data.freq[u,l]
-
-        prefac = self.emitters[emitName].data.levWgt[u] * \
-            np.exp(-self.emitters[emitName].levTemp[l]/T0) / (4*np.pi)
-
-        I0 = self.emitters[emitName].EinsteinA[u,l] * h * \
-            self.colDen * self.emitters[emitName].abundance
-        Theta = (self.emitters[emitName].levTemp[u] - \
-                     self.emitters[emitName].levTemp[l]) / T0
-        tau = self.colDen * self.emitters[emitName].abundance * \
-            self.emitters[emitName].EinsteinA[u,l] * c**2 / \
-            (2.0*self.emitters[emitName].freq[u,l]**3)
-        partFunc = self.emitters[emitName].partFunc
-        g0 = self.emitters[emitName].levWgt[l]
-        g1 = self.emitters[emitName].levWgt[u]
-
-        print T0, tau, boltzFac0, Theta, beta0, betas0, Mach0, \
-            offset, g0, g1
-
-        # Step 4: integrate the transfer equation at the specified
-        # velocities
-        iOut = np.zeros(len(vOut))
-        for i, v in enumerate(vOut):
-            f = 1 + v/c   # Frequency normalized to line-center value
-            iOut[i] = \
-                odeint(transferEqn, 0, \
-                                     [-np.sqrt(1.0-offset**2), \
-                                           np.sqrt(1.0-offset**2)], \
-                                     args=(f, T0, tau, Theta, \
-                                               beta0, betas0, \
-                                               Mach0, offset, \
-                                               g0, g1, boltzFac0, partFunc, \
-                                               denProf, TProf, \
-                                               vProf, sigmaProf))[1]
-
-        # Step 5: convert intensities to brightness temperatures
-        TB = h*self.emitters[emitName].freq[u,l]/kB / \
-            log(1.0+2.0*h*self.emitters[emitName].freq[u,l]**3 / \
-                    (c**2*iOut*I0))
-
-        # Step 6: return
-        return TB, vOut
-            
-
 
 ########################################################################
 # End of class gasProp
